@@ -10,21 +10,31 @@ from __future__ import annotations
 from abc import ABC, abstractmethod
 from typing import Any, List, Optional
 
-from concepttordf import Concept
-from datacatalogtordf import Agent, Resource, URI
-from rdflib import BNode, Graph, Literal, Namespace, RDF, URIRef
+from concepttordf import Concept, Contact
+from datacatalogtordf import Agent, Location, Resource, URI
+from datacatalogtordf.periodoftime import Date
+from rdflib import (
+    BNode,
+    DCTERMS,
+    FOAF,
+    Graph,
+    Literal,
+    Namespace,
+    OWL,
+    RDF,
+    SKOS,
+    URIRef,
+    XSD,
+)
 
 from modelldcatnotordf.licensedocument import LicenseDocument
 
-DCT = Namespace("http://purl.org/dc/terms/")
 DCAT = Namespace("http://www.w3.org/ns/dcat#")
 ODRL = Namespace("http://www.w3.org/ns/odrl/2/")
-XSD = Namespace("http://www.w3.org/2001/XMLSchema#")
 PROV = Namespace("http://www.w3.org/ns/prov#")
 MODELLDCATNO = Namespace("https://data.norge.no/vocabulary/modelldcatno#")
-FOAF = Namespace("http://xmlns.com/foaf/0.1/")
-SKOS = Namespace("http://www.w3.org/2004/02/skos/core#")
 XKOS = Namespace("http://rdf-vocabulary.ddialliance.org/xkos#")
+ADMS = Namespace("http://www.w3.org/ns/adms#")
 
 
 class InformationModel(Resource):
@@ -44,6 +54,15 @@ class InformationModel(Resource):
         "_is_replaced_by",
         "_has_part",
         "_is_part_of",
+        "_homepage",
+        "_contactpoints",
+        "_locations",
+        "_modified",
+        "_dct_type",
+        "_version_info",
+        "_version_note",
+        "_status",
+        "_creator",
     )
 
     _title: dict
@@ -56,6 +75,15 @@ class InformationModel(Resource):
     _is_replaced_by: List[InformationModel]
     _has_part: List[InformationModel]
     _is_part_of: List[InformationModel]
+    _homepage: URI
+    _contactpoints: List[Contact]
+    _locations: List[Location]
+    _modified: Date
+    _dct_type: Concept
+    _version_info: str
+    _version_note: dict
+    _status: Concept
+    _creator: Agent
 
     def __init__(self) -> None:
         """Inits InformationModel object with default values."""
@@ -67,6 +95,8 @@ class InformationModel(Resource):
         self._is_replaced_by = []
         self._has_part = []
         self._is_part_of = []
+        self._contactpoints = []
+        self._locations = []
 
     @property
     def informationmodelidentifier(self) -> str:
@@ -197,6 +227,96 @@ class InformationModel(Resource):
         """Set for is_part_of."""
         self._is_part_of = is_part_of
 
+    @property
+    def homepage(self: InformationModel) -> str:
+        """Get for homepage."""
+        return self._homepage
+
+    @homepage.setter
+    def homepage(self: InformationModel, homepage: str) -> None:
+        """Set for homepage."""
+        self._homepage = URI(homepage)
+
+    @property
+    def contactpoints(self: InformationModel) -> List[Contact]:
+        """Get for contactpoints."""
+        return self._contactpoints
+
+    @contactpoints.setter
+    def contactpoints(self: InformationModel, contactpoints: List[Contact]) -> None:
+        """Set for contactpoints."""
+        self._contactpoints = contactpoints
+
+    @property
+    def locations(self: InformationModel) -> List[Location]:
+        """Get for locations."""
+        return self._locations
+
+    @locations.setter
+    def locations(self: InformationModel, locations: List[Location]) -> None:
+        """Set for locations."""
+        self._locations = locations
+
+    @property
+    def modified(self: InformationModel) -> str:
+        """Get for modified."""
+        return self._modified
+
+    @modified.setter
+    def modified(self: InformationModel, modified: str) -> None:
+        """Set for modified."""
+        self._modified = Date(modified)
+
+    @property
+    def dct_type(self: InformationModel) -> Concept:
+        """Get for dct_type."""
+        return self._dct_type
+
+    @dct_type.setter
+    def dct_type(self: InformationModel, dct_type: Concept) -> None:
+        """Set for dct_type."""
+        self._dct_type = dct_type
+
+    @property
+    def version_info(self: InformationModel) -> str:
+        """Get for version_info."""
+        return self._version_info
+
+    @version_info.setter
+    def version_info(self: InformationModel, version_info: str) -> None:
+        """Set for version_info."""
+        self._version_info = version_info
+
+    @property
+    def version_note(self) -> dict:
+        """Get for version_note."""
+        return self._version_note
+
+    @version_note.setter
+    def version_note(self, version_note: dict) -> None:
+        """Set for version_note."""
+        self._version_note = version_note
+
+    @property
+    def status(self) -> Concept:
+        """Get for status."""
+        return self._status
+
+    @status.setter
+    def status(self, status: Concept) -> None:
+        """Set for status."""
+        self._status = status
+
+    @property
+    def creator(self: InformationModel) -> Agent:
+        """Get for creator."""
+        return self._creator
+
+    @creator.setter
+    def creator(self: InformationModel, creator: Agent) -> None:
+        """Set for creator."""
+        self._creator = creator
+
     def to_rdf(
         self: InformationModel,
         format: str = "turtle",
@@ -234,6 +354,12 @@ class InformationModel(Resource):
         self._is_replaced_by_to_graph()
         self._has_part_to_graph()
         self._is_part_of_to_graph()
+        self._homepage_to_graph()
+        self._contactpoints_to_graph()
+        self._locations_to_graph()
+        self._modified_to_graph()
+        self._dct_type_to_graph()
+        self._version_note_to_graph()
 
         if getattr(self, "informationmodelidentifier", None):
             self._g.add(
@@ -244,6 +370,24 @@ class InformationModel(Resource):
                 )
             )
 
+        if getattr(self, "version_info", None):
+            self._g.add(
+                (
+                    URIRef(self.identifier),
+                    OWL.versionInfo,
+                    Literal(self._version_info),
+                )
+            )
+
+        if getattr(self, "status", None):
+
+            _status = URIRef(self.status.identifier)
+
+            for _s, p, o in self.status._to_graph().triples((None, None, None)):
+                self._g.add((_status, p, o))
+
+            self._g.add((URIRef(self.identifier), ADMS.status, _status))
+
         return self._g
 
     def _subject_to_graph(self: InformationModel) -> None:
@@ -259,7 +403,7 @@ class InformationModel(Resource):
                 self._g.add(
                     (
                         URIRef(self.identifier),
-                        DCT.subject,
+                        DCTERMS.subject,
                         _subject,
                     )
                 )
@@ -309,7 +453,7 @@ class InformationModel(Resource):
                     else (_s, p, o)
                 )
 
-            self._g.add((URIRef(self.identifier), DCT.license, _licensedocument))
+            self._g.add((URIRef(self.identifier), DCTERMS.license, _licensedocument))
 
     def _replaces_to_graph(self: InformationModel) -> None:
         if getattr(self, "replaces", None):
@@ -324,7 +468,7 @@ class InformationModel(Resource):
                 self._g.add(
                     (
                         URIRef(self.identifier),
-                        DCT.replaces,
+                        DCTERMS.replaces,
                         _replaces,
                     )
                 )
@@ -342,7 +486,7 @@ class InformationModel(Resource):
                 self._g.add(
                     (
                         URIRef(self.identifier),
-                        DCT.isReplacedBy,
+                        DCTERMS.isReplacedBy,
                         _is_replaced_by,
                     )
                 )
@@ -360,7 +504,7 @@ class InformationModel(Resource):
                 self._g.add(
                     (
                         URIRef(self.identifier),
-                        DCT.hasPart,
+                        DCTERMS.hasPart,
                         _has_part,
                     )
                 )
@@ -378,11 +522,89 @@ class InformationModel(Resource):
                 self._g.add(
                     (
                         URIRef(self.identifier),
-                        DCT.isPartOf,
+                        DCTERMS.isPartOf,
                         _is_part_of,
                     )
                 )
 
+    def _homepage_to_graph(self: InformationModel) -> None:
+        if getattr(self, "homepage", None):
+            self._g.add((URIRef(self.identifier), FOAF.homepage, URIRef(self.homepage)))
+
+    def _contactpoints_to_graph(self: InformationModel) -> None:
+        if getattr(self, "contactpoints", None):
+
+            for contactpoint in self._contactpoints:
+
+                _contactpoint = BNode()
+
+                for _s, p, o in contactpoint._to_graph().triples((None, None, None)):
+                    self._g.add((_contactpoint, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCAT.contactPoint,
+                        _contactpoint,
+                    )
+                )
+
+    def _locations_to_graph(self: InformationModel) -> None:
+        if getattr(self, "locations", None):
+
+            for location in self._locations:
+
+                _location = BNode()
+
+                for _s, p, o in location._to_graph().triples((None, None, None)):
+                    self._g.add((_location, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCTERMS.spatial,
+                        _location,
+                    )
+                )
+
+    def _modified_to_graph(self: InformationModel) -> None:
+        if getattr(self, "modified", None):
+            self._g.add(
+                (
+                    URIRef(self.identifier),
+                    DCTERMS.modified,
+                    Literal(self.modified, datatype=XSD.date),
+                )
+            )
+
+    def _dct_type_to_graph(self: InformationModel) -> None:
+        if getattr(self, "dct_type", None):
+
+            _dct_type = URIRef(self.dct_type.identifier)
+
+            for _s, p, o in self.dct_type._to_graph().triples((None, None, None)):
+                self._g.add((_dct_type, p, o))
+
+            self._g.add(
+                (
+                    URIRef(self.identifier),
+                    DCTERMS.type,
+                    _dct_type,
+                )
+            )
+
+    def _version_note_to_graph(self: InformationModel) -> None:
+        if getattr(self, "version_note", None):
+
+            for key in self.version_note:
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        ADMS.versionNotes,
+                        Literal(self.version_note[key], lang=key),
+                    )
+                )
+
 
 class ModelElement(ABC):
     """A class representing a modelldcatno:ModelElement."""
@@ -485,7 +707,7 @@ class ModelElement(ABC):
         # Set up graph and namespaces:
         self._g = Graph()
         self._g.bind("modelldcatno", MODELLDCATNO)
-        self._g.bind("dct", DCT)
+        self._g.bind("dct", DCTERMS)
         self._g.bind("dcat", DCAT)
         self._g.bind("skos", SKOS)
         self._g.bind("xsd", XSD)
@@ -497,13 +719,13 @@ class ModelElement(ABC):
                 self._g.add(
                     (
                         selfobject,
-                        DCT.title,
+                        DCTERMS.title,
                         Literal(self.title[key], lang=key),
                     )
                 )
 
         if getattr(self, "dct_identifier", None):
-            self._g.add((selfobject, DCT.identifier, Literal(self._dct_identifier)))
+            self._g.add((selfobject, DCTERMS.identifier, Literal(self._dct_identifier)))
 
         if getattr(self, "subject", None):
 
@@ -512,7 +734,7 @@ class ModelElement(ABC):
             for _s, p, o in self.subject._to_graph().triples((None, None, None)):
                 self._g.add((_subject, p, o))
 
-            self._g.add((selfobject, DCT.subject, _subject))
+            self._g.add((selfobject, DCTERMS.subject, _subject))
 
         if getattr(self, "has_property", None):
             self._has_property_to_graph(selfobject)
@@ -657,7 +879,7 @@ class ModelProperty(ABC):
         # Set up graph and namespaces:
         self._g = Graph()
         self._g.bind("modelldcatno", MODELLDCATNO)
-        self._g.bind("dct", DCT)
+        self._g.bind("dct", DCTERMS)
         self._g.bind("skos", SKOS)
 
         self._g.add((selfobject, RDF.type, type))
@@ -675,7 +897,7 @@ class ModelProperty(ABC):
                 self._g.add(
                     (
                         selfobject,
-                        DCT.title,
+                        DCTERMS.title,
                         Literal(self.title[key], lang=key),
                     )
                 )
@@ -687,7 +909,7 @@ class ModelProperty(ABC):
             for _s, p, o in self.subject._to_graph().triples((None, None, None)):
                 self._g.add((_subject, p, o))
 
-            self._g.add((selfobject, DCT.subject, _subject))
+            self._g.add((selfobject, DCTERMS.subject, _subject))
 
         return self._g
 
@@ -1882,14 +2104,27 @@ class RootObjectType(ModelElement):
 class CodeList(ModelElement):
     """A class representing a modelldcatno:CodeList."""
 
+    __slots__ = ("_identifier", "_dct_identifier", "g", "_code_list_reference")
+
     _identifier: URI
     _dct_identifier: str
     _g: Graph
+    _code_list_reference: CodeList
 
     def __init__(self) -> None:
         """Inits an object with default values."""
         super().__init__()
 
+    @property
+    def code_list_reference(self: CodeList) -> CodeList:
+        """Get for code_list_reference."""
+        return self._code_list_reference
+
+    @code_list_reference.setter
+    def code_list_reference(self: CodeList, code_list_reference: CodeList) -> None:
+        """Set for code_list_reference."""
+        self._code_list_reference = code_list_reference
+
     def to_rdf(
         self: CodeList, format: str = "turtle", encoding: Optional[str] = "utf-8"
     ) -> str:
@@ -1924,8 +2159,29 @@ class CodeList(ModelElement):
 
         super(CodeList, self)._to_graph(MODELLDCATNO.CodeList, _self)
 
+        self._code_list_reference_to_graph(_self)
+
         return self._g
 
+    def _code_list_reference_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "code_list_reference", None):
+
+            if getattr(self.code_list_reference, "identifier", None):
+                _code_list_reference = URIRef(self.code_list_reference.identifier)
+            else:
+                _code_list_reference = BNode()
+                for _s, p, o in self.code_list_reference._to_graph().triples(
+                    (None, None, None)
+                ):
+                    self._g.add(
+                        (_code_list_reference, p, o)
+                        if isinstance(_code_list_reference, BNode)
+                        else (_s, p, o)
+                    )
+
+            self._g.add((_self, MODELLDCATNO.codeListReference, _code_list_reference))
+
 
 class CodeElement:
     """A class representing a modelldcatno:CodeElement."""
@@ -2173,13 +2429,13 @@ class CodeElement:
         # Set up graph and namespaces:
         self._g = Graph()
         self._g.bind("modelldcatno", MODELLDCATNO)
-        self._g.bind("dct", DCT)
+        self._g.bind("dct", DCTERMS)
         self._g.bind("skos", SKOS)
 
         self._g.add((_self, RDF.type, self._type))
 
         if getattr(self, "dct_identifier", None):
-            self._g.add((_self, DCT.identifier, Literal(self._dct_identifier)))
+            self._g.add((_self, DCTERMS.identifier, Literal(self._dct_identifier)))
 
         if getattr(self, "notation", None):
             self._g.add((_self, SKOS.notation, Literal(self._notation)))
@@ -2210,7 +2466,7 @@ class CodeElement:
             for _s, p, o in self.subject._to_graph().triples((None, None, None)):
                 self._g.add((_subject, p, o))
 
-            self._g.add((_self, DCT.subject, _subject))
+            self._g.add((_self, DCTERMS.subject, _subject))
 
     def _preflabel_to_graph(self, _self: Any) -> None:
 
@@ -2398,3 +2654,76 @@ class CodeElement:
                 )
 
             self._g.add((_self, XKOS.previous, _previous_element))
+
+
+class Note(ModelProperty):
+    """A class representing a modelldcatno:Note."""
+
+    __slots__ = "_property_note"
+
+    _property_note: dict
+    _identifier: URI
+    _g: Graph
+
+    @property
+    def property_note(self: Note) -> dict:
+        """Get for property_note."""
+        return self._property_note
+
+    @property_note.setter
+    def property_note(self: Note, property_note: dict) -> None:
+        """Set for property_note."""
+        self._property_note = property_note
+
+    def __init__(self) -> None:
+        """Inits an object with default values."""
+        super().__init__()
+
+    def to_rdf(
+        self: Note, format: str = "turtle", encoding: Optional[str] = "utf-8"
+    ) -> str:
+        """Maps the role to rdf.
+
+        Args:
+            format: a valid format. Default: turtle
+            encoding: the encoding to serialize into
+
+        Returns:
+            a rdf serialization as a string according to format.
+        """
+        return self._to_graph().serialize(format=format, encoding=encoding)
+
+    def _to_graph(
+        self: Note, type: str = MODELLDCATNO.Note, selfobject: Any = None
+    ) -> Graph:
+        """Returns the role as graph.
+
+        Args:
+            type: type for identifying class. Default: MODELLDCATNO.Note
+            selfobject: a bnode or URI passed from a subclass Default: None
+
+        Returns:
+            the role graph
+        """
+        if getattr(self, "identifier", None):
+            _self = URIRef(self.identifier)
+        else:
+            _self = BNode()
+
+        super(Note, self)._to_graph(MODELLDCATNO.Note, _self)
+
+        self._property_note_to_graph(_self)
+
+        return self._g
+
+    def _property_note_to_graph(self: Note, _self: Any) -> None:
+        if getattr(self, "property_note", None):
+
+            for key in self.property_note:
+                self._g.add(
+                    (
+                        _self,
+                        MODELLDCATNO.propertyNote,
+                        Literal(self.property_note[key], lang=key),
+                    )
+                )
